==> katalog_0.3.orig.tar.gz: katalog-0.3/katalogdcop/main.cpp <==
/***************************************************************************
 *   Copyright (C) 2004 by Stefano Salvador                                *
 *   salva_ste@tin.it                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <kuniqueapplication.h>
#include <kaboutdata.h>
#include <kcmdlineargs.h>
#include <kdebug.h>
#include <kaboutdata.h>
#include <klocale.h>
#include <dcopclient.h>
#include "katalogdcop.h"

static const char description[] =
    I18N_NOOP("A KDE KPart Application");

static const char version[] = "0.3";

static KCmdLineOptions options[] =
{
    KCmdLineLastOption
};

int main (int argc, char *argv[])
{
	KLocale::setMainCatalogue("kdelibs");
	KAboutData aboutdata("katalogdcop", I18N_NOOP("KDE"),
				version, description,
				KAboutData::License_GPL, "(C) 2004, Stefano Salvador");
	aboutdata.addAuthor("Stefano Salvador",I18N_NOOP("Developer"),"salva_ste@tin.it");

	KCmdLineArgs::init( argc, argv, &aboutdata );
	KCmdLineArgs::addCmdLineOptions( options );
	KUniqueApplication::addCmdLineOptions();

	if (!KUniqueApplication::start())
	{
		kdDebug() << "katalogdcop is already running!" << endl;
		return (0);
	}

	KUniqueApplication app;
	kdDebug() << "starting katalogdcop " << endl;
	// This app is started automatically, no need for session management
	app.disableSessionManagement();
	katalogdcop *service = new katalogdcop;
	kdDebug() << "starting katalogdcop " << endl;
	return app.exec();

}

==> katalog-0.4.tar.gz: katalog-0.4/katalogdcop/main.cpp <==
/***************************************************************************
 *   Copyright (C) 2004 by Stefano Salvador                                *
 *   stefano.salvador@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <kuniqueapplication.h>
#include <kaboutdata.h>
#include <kcmdlineargs.h>
#include <kdebug.h>
#include <kaboutdata.h>
#include <klocale.h>
#include <dcopclient.h>
#include "katalogdcop.h"

static const char description[] =
    I18N_NOOP("A KDE KPart Application");

static const char version[] = "0.3";

static KCmdLineOptions options[] =
{
    KCmdLineLastOption
};

int main (int argc, char *argv[])
{
	KLocale::setMainCatalogue("kdelibs");
	KAboutData aboutdata("katalogdcop", I18N_NOOP("KDE"),
				version, description,
				KAboutData::License_GPL, "(C) 2004, Stefano Salvador");
	aboutdata.addAuthor("Stefano Salvador",I18N_NOOP("Developer"),"stefano.salvador@gmail.com");

	KCmdLineArgs::init( argc, argv, &aboutdata );
	KCmdLineArgs::addCmdLineOptions( options );
	KUniqueApplication::addCmdLineOptions();

	if (!KUniqueApplication::start())
	{
		return (0);
	}

	KUniqueApplication app;
	// This app is started automatically, no need for session management
	app.disableSessionManagement();
	katalogdcop *service = new katalogdcop;
	return app.exec();

}
